@@ -16,21 +16,17 @@ mkde <- function(x, h, thumb = "none") {
   ## h is the h you want, which is either a vector or a single number
   ## thumb can be either "none" so the specified h is used, or
   ## "scott", or "silverman"
-
   n <- dim(x)[1]
   d <- dim(x)[2]  ## sample and dimensionality of x
 
   if ( thumb == "silverman" ) {
     s <- Rfast::colVars(x, std = TRUE)
     h <- ( 4/(d + 2) )^( 1/(d + 4) ) * s * n^( -1/(d + 4) )
-
   } else  if ( thumb == "scott" ) {
     s <- Rfast::colVars(x, std = TRUE)
     h <- s * n^( -1/(d + 4) )
-
   } else if ( thumb == "estim" ) {
     h <- mkde.tune(x)$hopt
-
   } else  h <- h
 
   if ( length(h) == 1 ) {
@@ -39,7 +35,6 @@ mkde <- function(x, h, thumb = "none") {
 
   con <- prod( diag( h ) )
   y <- x %*% h
-  a1 <- fields::rdist(y, compact = FALSE)
-  (0.5 / pi)^(d/2) * con * Rfast::rowmeans( exp(-0.5 * a1^2 ) )
-
+  a1 <- Rfast::Dist(y, method = "euclidean", square = TRUE)
+  (0.5 / pi)^(d/2) * con * Rfast::rowmeans( exp(-0.5 * a1 ) )
 }
